function [s,p,q] = standard(y,yv0,vk0,N,prprt)
%A basic standard equilibrium wall function adapted to work in the present
%framework

%0) Let be sure N is actually within allowed bounds (-1<=N)
N=max(-1,N);

%1) Check if velocity case and compute profile constants
nmax=100;
E=exp(vk0*yv0)/yv0;
velo = prprt<=0;
if ~velo
    k=prprt;
    P=9.24*((k^0.75-1)*(1+0.28*exp(-0.007*k)));
    yv=yv0*max(1/k,(1/k)^(1/3));
    for i = 1:nmax
        f0=log(E*yv)/vk0+P;
        f1=k*yv-f0;
        df1=k-1/(vk0*yv);
        f2=2*df1*f1;
        df2=2*df1^2-f1/(vk0*yv^2);

        if df2~=0 %Halley method
            yvn = yv - f2/df2;
        else
            if df1~=0 %Newton method
                yvn = yv - f1/df1;
            else %Fixed point iteration
                yvn = f0/k;
            end
        end
        err=abs(f1);
        if ((err<1e-10*yv)&&(abs(yv-yvn)<1e-10*yv))
            break
        end
        yv=yvn;
    end
else
    k=1;
    yv=yv0;
    P=0;
end

%2) Assembling the profiles
s=zeros(1,N+2);
p=zeros(1,2*N+1+2); %Note p dimension bigger than s
q=zeros(1,N+2);

if y<=yv %Low y+ case: use known limiting behavior
    s(1)=1;
else     %General case
    s(1) = (log(E*y)/vk0+P)/(k*y);
    q(1) = (1/(1+k*vk0*y)-s(1))/y^2;
    p(1) = log(y/yv)/(vk0*y);
end