function [s,p,q] = standardsp(y,yv,vk0,N,prprt)
%The function returns the non-dimensional functions si/y+^(i+2) and pi/y+^(i+2)
%for the standard wall function (mutmu=ky+ for y+>=yv+, mutmu=0 for y+<yv+).
%Functions q are instead needed in computing the derivatives for the NR
%iterations
%N is the higher degree in the expansion and should be -1 to exclude the
%non equilibrium terms.
%The thermal case is handled by passing in prprt=pr/pr_t. When the
%paremeter is present, the average kinetic energy production is not computed. 

%0) Let be sure N is actually within allowed bounds (-1<=N)
N=max(-1,N);

%1) Check if velocity case
velo = prprt<=0;
if ~velo
    k=prprt;
    %Determine new yt for Pr>Prt
    if (k>1)
        [yv,~,~] = iteryv(yv,vk0,prprt,10);
    end
else
    k=1;
end

%2) Assembling the profiles
s=zeros(1,N+2);
p=zeros(1,2*N+1+2); %Note p dimension bigger than s
q=zeros(1,N+2);

if y<=yv %Low y+ case: use known limiting behavior
    %s
    for i=-1:N
        s(i+2)=1/(i+2);
        q(i+2)=0;
    end
    %p
    if velo
        for i=-1:2*N+1
            p(i+2)=0;
        end
    end
else       %General case
    %s
    for i=-1:N
        j=i+2;
        fact=(-1)^(i+1)/(k*vk0)^j;
        s(j) = yv^j/j+fact*(log((1+k*vk0*y)/(1+k*vk0*yv)));
        for m=1:i+1
            s(j)=s(j)+fact*(-k*vk0)^m*(y^m-yv^m)/m;
        end
        s(j)=s(j)/y^j;
        q(j)=(1/(1+k*vk0*y)-j*s(j))/y^2;
    end
    %p
    if velo
        for i=-1:2*N+1
            j=i+2;
            fact=(-1)^(i+1)/vk0^j;
            p(j) = fact*(j*log((1+vk0*y)/(1+vk0*yv))+(yv-y)/((1+yv)*(1+y)));
            for m=1:i+1
                p(j) = p(j) + fact*(j+m)*(-vk0)^m*(y^m-yv^m)/m;
            end
            p(j)=p(j)/y^j;
        end
    end
end