%Script to compare a number of different wall function models for U+, T+,
%P+ and mut/mu
clear all
close all
clc

%number of points for plots
np=10000;

%number of models
% 1: Standard analytical
% 2: New standard analytical
% 3: Musker Analytical
% 4: Spalart-Allmaras
% 5: Mixing length
nm=5;

%Flow parameters
Ud   = 27.58;
Uw   = 0;
Td   = 320;
Tw   = 300;
d    = 1;
rho  = 1;
mu   = 1/8000;
cp   = 1000;
pr   = 0.001;
prt  = 1;
dpdx = 0;
qdot = 0;
%**************************************************************************

Re = rho*(Ud-Uw)*d/mu;
Fu = rho*dpdx*d^3/mu^2;
cypl = abs(Fu)^(2/3);
cut  = (mu*abs(dpdx)/rho^2)^(2/3);
prprt=pr/prt;
qs=-qdot;

cc = cell(nm,9);
utmax=0;
for i=1:nm
    switch i
        case 1
            a0   = 10.224;
            vk0  = 0.384;
            mutmu = @(y,a,vk) vk*y.*(y>a);
            ff = @(x,a,vk,N,prr) standard(x,a,vk,N,prr);
            leg='Standard';
            pl='-';
        case 2
            a0   = 10.960;
            vk0  = 0.384;
            mutmu = @(y,a,vk) vk*y.*(y>a);
            ff = @(x,a,vk,N,prr) standardsp(x,a,vk,N,prr);
            leg='Standard New';
            pl='-.';
        case 3
            a0   = 10.306;
            vk0  = 0.384;
            mutmu = @(y,a,vk) (vk*y).^3./((vk*y).^2+(vk*a)^3-(vk*a)^2);
            ff = @(x,a,vk,N,prr) muskersp(x,a,vk,N,prr);
            leg='Musker';
            pl='-';
        case 4
            vk0   = 0.384;
            a0    = 4.622838269107443/vk0;
            mutmu = @(y,a,vk) (vk*y).^4./((vk*y).^3+(vk*a)^4-(vk*a)^3+256*eps);
            ff = @(x,a,vk,N,prr) numericalsp(x,@(y) mutmu(y,a,vk),N,prr);
            leg='Spalart-Allmaras';
            pl='-';
        case 5
            a0    = 15.24;
            vk0   = 0.384;
            mutmu = @(y,a,vk) (vk*y).*(1-exp(-y/a)).^2;
            ff = @(x,a,vk,N,prr) numericalsp(x,@(y) mutmu(y,a,vk),N,prr);
            leg='Mixing length';
            pl='-';
        otherwise
            error('Maximum nm is 5')
    end
    [ait,fait,nit] = spiter(Re,Fu,cypl,@(x) ff(x,a0,vk0,0,1));
    tw = mu^2*ait(nit)/(rho*d^2);
    ut = sqrt(abs(tw)/rho+cut);
    utmax = max(utmax,ut);
    cc(i,1:9)={a0, vk0, tw, ut, mutmu, ff, zeros(np,7), pl, leg};
end

y=logspace(-(2+log10(rho*utmax/mu)),log10(d),np)';

uu=zeros(np,1);
tt=zeros(np,1);
pp=zeros(np,1);
mm=zeros(np,1);
ed=zeros(np,1);

for i=1:nm
    a0  = cc{i,1};
    vk0 = cc{i,2};
    tw  = cc{i,3};
    ut  = cc{i,4};
    ypl = y*rho*ut/mu;
    [s,~,~] = cc{i,6}(ypl(np),a0,vk0,0,prprt);
    qw = (((Td-Tw)/d)*(mu*cp/pr)-d*s(2)*qs)/s(1);
    for j = 1:np
        [s,p,~] = cc{i,6}(ypl(j),a0,vk0,0,0);
        uu(j) = Uw + (tw*s(1) + dpdx*y(j)*s(2))*y(j)/mu;
        pp(j) = (tw^2*p(1)+2*tw*y(j)*dpdx*p(2)+p(3)*(y(j)*dpdx)^2)/mu;
        [s,~,~] = cc{i,6}(ypl(j),a0,vk0,0,prprt);
        tt(j) = Tw + (qw*s(1) + qs*y(j)*s(2))*y(j)*pr/(mu*cp);
    end
    mm = cc{i,5}(ypl,a0,vk0);
    dm = (rho*ut*pr/(2*mu*cp))*((cc{i,5}(ypl+0.001,a0,vk0)-mm)*1000)*(1-prprt).*(uu.^2)./(1+prprt*mm).^2;
    ed = -cumtrapz(y,dm);
    dd = (pr/(2*cp))*(uu.^2).*(1+mm)./(1+prprt*mm);
    cc{i,7} = [ypl, (uu-Uw)/ut, (tt-Tw)*rho*cp*ut/qw, pp*mu/tw^2, mm, dd, ed];
end

figure()
for i = 1:nm
    semilogx(cc{i,7}(:,1),cc{i,7}(:,2),cc{i,8})
    hold on
end
xlabel('y^+')
ylabel('U^+')
legend(cc{:,9},'Location','Best')

figure()
for i = 1:nm
    loglog(cc{i,7}(:,1),cc{i,7}(:,5),cc{i,8})
    hold on
end
xlabel('y^+')
ylabel('\mu_t/\mu')
legend(cc{:,9},'Location','Best')

figure()
for i = 1:nm
    semilogx(cc{i,7}(:,1),cc{i,7}(:,4),cc{i,8})
    hold on
end
xlabel('y^+')
ylabel('P^+')
legend(cc{:,9},'Location','Best')

figure()
for i = 1:nm
    semilogx(cc{i,7}(:,1),cc{i,7}(:,3),cc{i,8})
    hold on
end
xlabel('y^+')
ylabel('T^+')
legend(cc{:,9},'Location','Best')
